@@ -10,16 +10,20 @@ import re
 import aiohttp
 from aiohttp.client_exceptions import ContentTypeError
 from bs4 import BeautifulSoup
+
 from pyalarmdotcomajax.helpers import slug_to_title
 
 from . import const as c
-from .devices import BaseDevice
-from .devices import DEVICE_URLS
-from .devices import DeviceType
-from .devices import ElementSpecificData
-from .devices import TroubleCondition
+from .devices import (
+    DEVICE_URLS,
+    BaseDevice,
+    DeviceType,
+    ElementSpecificData,
+    TroubleCondition,
+)
 from .devices.camera import Camera
 from .devices.garage_door import GarageDoor
+from .devices.gate import Gate
 from .devices.image_sensor import ImageSensor
 from .devices.light import Light
 from .devices.lock import Lock
@@ -27,17 +31,21 @@ from .devices.partition import Partition
 from .devices.sensor import Sensor
 from .devices.system import System
 from .devices.thermostat import Thermostat
-from .errors import AuthenticationFailed
-from .errors import BadAccount
-from .errors import DataFetchFailed
-from .errors import NagScreen
-from .errors import UnexpectedDataStructure
-from .errors import UnsupportedDevice
-from .extensions import CameraSkybellControllerExtension
-from .extensions import ConfigurationOption
-from .extensions import ExtendedProperties
+from .errors import (
+    AuthenticationFailed,
+    BadAccount,
+    DataFetchFailed,
+    NagScreen,
+    UnexpectedDataStructure,
+    UnsupportedDevice,
+)
+from .extensions import (
+    CameraSkybellControllerExtension,
+    ConfigurationOption,
+    ExtendedProperties,
+)
 
-__version__ = "0.4.7"
+__version__ = "0.4.9"
 
 log = logging.getLogger(__name__)
 
@@ -45,6 +53,7 @@ log = logging.getLogger(__name__)
 DEVICE_CLASSES: dict = {
     DeviceType.CAMERA: Camera,
     DeviceType.GARAGE_DOOR: GarageDoor,
+    DeviceType.GATE: Gate,
     DeviceType.IMAGE_SENSOR: ImageSensor,
     DeviceType.LIGHT: Light,
     DeviceType.LOCK: Lock,
@@ -146,6 +155,7 @@ class AlarmController:
         self.sensors: list[Sensor] = []
         self.locks: list[Lock] = []
         self.garage_doors: list[GarageDoor] = []
+        self.gates: list[Gate] = []
         self.image_sensors: list[ImageSensor] = []
         self.lights: list[Light] = []
         self.cameras: list[Camera] = []
@@ -346,6 +356,7 @@ class AlarmController:
         event: Lock.Command
         | Partition.Command
         | GarageDoor.Command
+        | Gate.Command
         | Light.Command
         | ImageSensor.Command
         | Thermostat.Command,
@@ -509,6 +520,7 @@ class AlarmController:
             *self.sensors,
             *self.locks,
             *self.garage_doors,
+            *self.gates,
             *self.image_sensors,
             *self.lights,
             *self.cameras,
@@ -562,8 +574,10 @@ class AlarmController:
 
             except DataFetchFailed:
                 log.error(
-                    "Encountered data error while fetching %ss. Skipping this device"
-                    " type.",
+                    (
+                        "Encountered data error while fetching %ss. Skipping this"
+                        " device type."
+                    ),
                     device_type.name,
                 )
 
@@ -583,8 +597,7 @@ class AlarmController:
                     ):
                         skybells.append((device_json, None))
 
-                devices = skybells
-                if not devices:
+                if not (devices := skybells):
                     pass
 
             #
@@ -723,6 +736,8 @@ class AlarmController:
                 self.sensors[:] = temp_device_storage
             elif device_class is GarageDoor:
                 self.garage_doors[:] = temp_device_storage
+            elif device_class is Gate:
+                self.gates[:] = temp_device_storage
             elif device_class is Lock:
                 self.locks[:] = temp_device_storage
             elif device_class is Light:
@@ -852,8 +867,10 @@ class AlarmController:
 
         except aiohttp.ContentTypeError as err:
             log.error(
-                "Server returned wrong content type. Response: %s\n\nResponse"
-                " Text:\n\n%s\n\n",
+                (
+                    "Server returned wrong content type. Response: %s\n\nResponse"
+                    " Text:\n\n%s\n\n"
+                ),
                 resp,
                 resp.text(),
             )
@@ -920,9 +937,11 @@ class AlarmController:
 
             if rsp_errors[0].get("status") == "423":
                 log.debug(
-                    "Error fetching data from Alarm.com. This account either doesn't"
-                    " have permission to %s, is on a plan that does not support %s, or"
-                    " is part of a system with %s turned off.",
+                    (
+                        "Error fetching data from Alarm.com. This account either"
+                        " doesn't have permission to %s, is on a plan that does not"
+                        " support %s, or is part of a system with %s turned off."
+                    ),
                     device_type,
                     device_type,
                     device_type,
@@ -942,8 +961,10 @@ class AlarmController:
 
                 if not retry_on_failure:
                     log.debug(
-                        "Got 403 status when fetching data for device type %s. Logging"
-                        " in again didn't help.",
+                        (
+                            "Got 403 status when fetching data for device type %s."
+                            " Logging in again didn't help."
+                        ),
                         device_type,
                     )
 
