@@ -4,9 +4,7 @@ from __future__ import annotations
 from enum import Enum
 import logging
 
-from . import BaseDevice
-from . import DesiredStateMixin
-from . import DeviceType
+from . import BaseDevice, DesiredStateMixin, DeviceType
 
 log = logging.getLogger(__name__)
 
