@@ -7,9 +7,7 @@ import logging
 
 from pyalarmdotcomajax.errors import UnexpectedDataStructure
 
-from . import BaseDevice
-from . import DesiredStateMixin
-from . import DeviceType
+from . import BaseDevice, DesiredStateMixin, DeviceType
 
 log = logging.getLogger(__name__)
 
